@@ -1,35 +1,29 @@
-require 'test_helper'
-require 'tilt'
-require 'thread'
+require_relative 'test_helper'
 
-class CompileSiteTest < Minitest::Test
-  def setup
+describe 'tilt compile site' do
+  before do
     GC.start
   end
 
-  class CompilingTemplate < Tilt::Template
-    def prepare
-    end
-
+  _CompilingTemplate = Class.new(Tilt::Template) do
     def precompiled_template(locals)
       @data.inspect
     end
   end
 
-  class Scope
-  end
+  _Scope = Class.new
 
-  test "compiling template source to a method" do
-    template = CompilingTemplate.new { |t| "Hello World!" }
-    template.render(Scope.new)
+  it "compiling template source to a method" do
+    template = _CompilingTemplate.new { |t| "Hello World!" }
+    template.render(_Scope.new)
     method = template.send(:compiled_method, [])
     assert_kind_of UnboundMethod, method
   end
 
-  # This test attempts to surface issues with compiling templates from
+  # This it attempts to surface issues with compiling templates from
   # multiple threads.
-  test "using compiled templates from multiple threads" do
-    template = CompilingTemplate.new { 'template' }
+  it "using compiled templates from multiple threads" do
+    template = _CompilingTemplate.new { 'template' }
     main_thread = Thread.current
     10.times do |i|
       threads =
@@ -37,9 +31,9 @@ class CompileSiteTest < Minitest::Test
           Thread.new {
             begin
               locals = { "local#{i}" => 'value' }
-              res = template.render(self, locals)
+              template.render(self, locals)
               thread_id = Thread.current.object_id
-              res = template.render(self, "local#{thread_id.abs.to_s}" => 'value')
+              template.render(self, "local#{thread_id.abs.to_s}" => 'value')
             rescue => boom
               main_thread.raise(boom)
             end
